==> aliyun-python-sdk-das-1.0.9.tar.gz: aliyun-python-sdk-das-1.0.9/aliyunsdkdas/request/v20200116/EnableSqlConcurrencyControlRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdas.endpoint import endpoint_data

class EnableSqlConcurrencyControlRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'DAS', '2020-01-16', 'EnableSqlConcurrencyControl','das')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SqlType(self):
		return self.get_query_params().get('SqlType')

	def set_SqlType(self,SqlType):
		self.add_query_param('SqlType',SqlType)

	def get_SqlKeywords(self):
		return self.get_query_params().get('SqlKeywords')

	def set_SqlKeywords(self,SqlKeywords):
		self.add_query_param('SqlKeywords',SqlKeywords)

	def get_ConsoleContext(self):
		return self.get_query_params().get('ConsoleContext')

	def set_ConsoleContext(self,ConsoleContext):
		self.add_query_param('ConsoleContext',ConsoleContext)

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_ConcurrencyControlTime(self):
		return self.get_query_params().get('ConcurrencyControlTime')

	def set_ConcurrencyControlTime(self,ConcurrencyControlTime):
		self.add_query_param('ConcurrencyControlTime',ConcurrencyControlTime)

	def get_MaxConcurrency(self):
		return self.get_query_params().get('MaxConcurrency')

	def set_MaxConcurrency(self,MaxConcurrency):
		self.add_query_param('MaxConcurrency',MaxConcurrency)

==> aliyun-python-sdk-das-2.0.36.tar.gz: aliyun-python-sdk-das-2.0.36/aliyunsdkdas/request/v20200116/EnableSqlConcurrencyControlRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdas.endpoint import endpoint_data

class EnableSqlConcurrencyControlRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'DAS', '2020-01-16', 'EnableSqlConcurrencyControl')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_SqlType(self): # String
		return self.get_query_params().get('SqlType')

	def set_SqlType(self, SqlType):  # String
		self.add_query_param('SqlType', SqlType)
	def get_SqlKeywords(self): # String
		return self.get_query_params().get('SqlKeywords')

	def set_SqlKeywords(self, SqlKeywords):  # String
		self.add_query_param('SqlKeywords', SqlKeywords)
	def get_ConsoleContext(self): # String
		return self.get_query_params().get('ConsoleContext')

	def set_ConsoleContext(self, ConsoleContext):  # String
		self.add_query_param('ConsoleContext', ConsoleContext)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_ConcurrencyControlTime(self): # Long
		return self.get_query_params().get('ConcurrencyControlTime')

	def set_ConcurrencyControlTime(self, ConcurrencyControlTime):  # Long
		self.add_query_param('ConcurrencyControlTime', ConcurrencyControlTime)
	def get_MaxConcurrency(self): # Long
		return self.get_query_params().get('MaxConcurrency')

	def set_MaxConcurrency(self, MaxConcurrency):  # Long
		self.add_query_param('MaxConcurrency', MaxConcurrency)
